"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.existsDirectory = exports.currentPath = exports.projectPath = exports.parseArgumentOptions = exports.loadGoqooConfig = exports.usageExit = exports.showVersion = exports.trim = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const minimist_1 = __importDefault(require("minimist"));
const minimist_options_1 = __importDefault(require("minimist-options"));
const netrc_parser_1 = __importDefault(require("netrc-parser"));
const caller_1 = __importDefault(require("caller"));
const cosmiconfig_1 = require("cosmiconfig");
const trim = (text) => text.replace(/^\n|\n$/g, '');
exports.trim = trim;
const showVersion = () => {
    const { version } = require('../package.json');
    const { version: templateVersion } = require('@goqoo/templates/package.json');
    console.error(`Goqoo    version: ${version}`);
    console.error(`Template version: ${templateVersion}`);
    process.exit(0);
};
exports.showVersion = showVersion;
const usageExit = (returnCode = 0) => {
    const message = (0, exports.trim)(`
usage: goqoo [-v, --version] [-h, --help]
              new <project name>
              generate <GENERATOR> <app name>
              start
              build
              watch
              release
`);
    console.error(message);
    process.exit(returnCode);
};
exports.usageExit = usageExit;
const loadGoqooConfig = () => {
    const goqooConfig = (0, cosmiconfig_1.cosmiconfigSync)('goqoo').search()?.config;
    if (!goqooConfig) {
        throw new Error('goqoo config file not found');
    }
    return goqooConfig;
};
exports.loadGoqooConfig = loadGoqooConfig;
const parseArgumentOptions = () => {
    const argv = (0, minimist_1.default)(process.argv.slice(2), (0, minimist_options_1.default)({
        version: {
            type: 'boolean',
            alias: 'v',
        },
        help: {
            type: 'boolean',
            alias: 'h',
        },
        port: {
            type: 'number',
            alias: 'p',
            default: 59000,
        },
    }));
    if (argv._[0]) {
        argv._subCommand = argv._[0];
        argv._options = argv._.slice(1);
    }
    return argv;
};
exports.parseArgumentOptions = parseArgumentOptions;
// TODO: この関数は抜本的に見直す
const createOptionValues = async () => {
    const argv = (0, exports.parseArgumentOptions)();
    if (!argv.type) {
        if (argv.version) {
            (0, exports.showVersion)();
        }
        else if (argv.help) {
            (0, exports.usageExit)(0);
        }
        else {
            (0, exports.usageExit)(1);
        }
    }
    // netrcに保存済みの情報取得
    netrc_parser_1.default.loadSync();
    const opts = {};
    opts.help = argv.help;
    opts.type = argv.type;
    opts._ = argv._;
    return opts;
};
const projectPath = (...args) => path_1.default.resolve(...args);
exports.projectPath = projectPath;
const currentPath = (...args) => {
    const dir = path_1.default.dirname((0, caller_1.default)());
    return path_1.default.resolve(dir, ...args);
};
exports.currentPath = currentPath;
const existsDirectory = (directory) => {
    if (!fs_1.default.existsSync(directory) || !fs_1.default.statSync(directory).isDirectory()) {
        return false;
    }
    return true;
};
exports.existsDirectory = existsDirectory;
