"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_1 = require("child_process");
const fs_1 = require("fs");
const util_1 = require("../_common/util");
const main = async (argv) => {
    const { bundlerType, nodeEnv = 'development' } = (0, util_1.loadGoqooConfig)();
    if (!process.env.NODE_ENV) {
        process.env.NODE_ENV = nodeEnv;
    }
    console.info({ bundlerType, nodeEnv: process.env.NODE_ENV });
    const webpackBinPath = (0, util_1.currentPath)('../../node_modules/.bin/webpack');
    let webpackDefaultConfigPath;
    switch (bundlerType) {
        case 'react':
            webpackDefaultConfigPath = (0, util_1.currentPath)('./webpack.config.react.js');
            break;
        case 'vue':
            webpackDefaultConfigPath = (0, util_1.currentPath)('./webpack.config.vue.js');
            break;
        case 'default':
        default:
            webpackDefaultConfigPath = (0, util_1.currentPath)('./webpack.config.js');
    }
    const webpackCustomConfigPath = (0, util_1.projectPath)('./webpack.config.js');
    const webpackConfigPath = (0, fs_1.existsSync)(webpackCustomConfigPath) ? webpackCustomConfigPath : webpackDefaultConfigPath;
    const options = argv._options.join(' ');
    const webpackCommandBase = `'${webpackBinPath}' ${options} --progress --config '${webpackConfigPath}'`;
    const exec = (command) => (0, child_process_1.execSync)(command, { stdio: 'inherit' });
    switch (argv._subCommand) {
        case 'build': {
            exec(`${webpackCommandBase} --mode development`);
            break;
        }
        case 'watch': {
            exec(`${webpackCommandBase} --mode development --watch`);
            break;
        }
        case 'release': {
            exec(`${webpackCommandBase} --mode production`);
            break;
        }
        case 'start':
        case 's': {
            const port = process.env.GOQOO_PORT ?? argv.port;
            exec(`'${webpackBinPath}' serve ${options} --port ${port} --progress --config '${webpackConfigPath}' --mode development`);
            break;
        }
        default: {
            (0, util_1.usageExit)(1);
        }
    }
};
exports.default = async (argv) => {
    try {
        await main(argv);
    }
    catch (e) {
        console.error(e);
    }
};
