"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = void 0;
const cross_spawn_1 = __importDefault(require("cross-spawn"));
const fs_1 = require("fs");
const chalk_1 = __importDefault(require("chalk"));
const change_case_1 = require("change-case");
const dotenv_1 = __importDefault(require("dotenv"));
// @ts-ignore
const util_1 = require("../../_common/util");
const oauth_1 = require("../../_common/oauth");
const run = async (config) => {
    const { dtsGen } = config;
    const envName = dtsGen?.env;
    const context = config.environments.find((c) => c.env === envName);
    if (!context) {
        throw new Error('dts-gen context not found!');
    }
    dotenv_1.default.config({ path: (0, util_1.projectPath)(`.env.${envName}`) });
    const distDir = 'dts';
    (0, fs_1.mkdirSync)(distDir, { recursive: true });
    const connection = { 'base-url': `https://${context.host}` };
    const auth = context.auth ?? {};
    auth.type ??= 'password';
    switch (auth.type) {
        case 'oauth': {
            connection['oauth-token'] = await (0, oauth_1.getOauthToken)({
                domain: context.host,
                scope: auth.scope,
                proxy: auth.proxy,
                pfx: auth.pfx,
            });
            break;
        }
        case 'apiToken': {
            connection['basic-auth-username'] = process.env.GOQOO_BASICAUTH_USERNAME;
            connection['basic-auth-password'] = process.env.GOQOO_BASICAUTH_PASSWORD;
            break;
        }
        case 'password':
        default: {
            // TODO: netrcや標準入力に対応
            connection['username'] = process.env.GOQOO_USERNAME;
            connection['password'] = process.env.GOQOO_PASSWORD;
            connection['basic-auth-username'] = process.env.GOQOO_BASICAUTH_USERNAME;
            connection['basic-auth-password'] = process.env.GOQOO_BASICAUTH_PASSWORD;
            break;
        }
    }
    const skipApps = dtsGen?.skip || [];
    Object.entries(context.appId).forEach(([appName, appId]) => {
        if (skipApps.includes(appName)) {
            return;
        }
        if (auth.type === 'apiToken') {
            connection['api-token'] = process.env[`GOQOO_API_TOKEN_${appName.toUpperCase()}`];
        }
        const args = {
            ...connection,
            'type-name': `${(0, change_case_1.pascalCase)(appName)}Fields`,
            'app-id': appId,
            'output': `${distDir}/${(0, change_case_1.paramCase)(appName)}-fields.d.ts`,
        };
        const { status } = cross_spawn_1.default.sync('npx', ['kintone-dts-gen', ...Object.entries(args).map(([key, value]) => `--${key}=${value}`)], {
            cwd: (0, util_1.projectPath)('./'),
            stdio: 'inherit',
        });
        if (status === 0) {
            console.info(`${chalk_1.default.cyan('info')} ${chalk_1.default.magenta('Created')} ${chalk_1.default.green(args.output)}`);
        }
        else {
            console.info(`${chalk_1.default.red('error')} Failed of generating ${chalk_1.default.yellow(args.output)} (authType: ${auth.type})`);
        }
    });
};
exports.run = run;
