"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.errorDialog = exports.successDialog = exports.confirmDialog = exports.helloGoqoo = void 0;
const sweetalert_1 = __importDefault(require("sweetalert"));
const clipboard_copy_1 = __importDefault(require("clipboard-copy"));
const _1 = require(".");
// @ts-expect-error
const logo_jpg_1 = __importDefault(require("../../img/logo.jpg"));
const helloGoqoo = async () => {
    return (0, sweetalert_1.default)({
        text: 'Hello, Goqoo on kintone!',
        icon: logo_jpg_1.default,
    });
};
exports.helloGoqoo = helloGoqoo;
const confirmDialog = async (swalParams) => {
    const customParams = typeof swalParams === 'string' ? { text: swalParams } : swalParams;
    return (0, sweetalert_1.default)({
        icon: 'info',
        buttons: {
            cancel: true,
            confirm: {
                closeModal: false,
            },
        },
        closeOnClickOutside: false,
        closeOnEsc: false,
        ...customParams,
    }).then((result) => {
        const cancelButton = document.querySelector('.swal-button--cancel');
        cancelButton?.parentNode?.removeChild(cancelButton);
        return result;
    });
};
exports.confirmDialog = confirmDialog;
const successDialog = async (text) => {
    return (0, sweetalert_1.default)({ icon: 'success', text });
};
exports.successDialog = successDialog;
const errorDialog = async (e) => {
    // NOTE: 型を無視してError以外のオブジェクトやstring以外のプリミティブ型が渡されても
    // ダイアログは落ちずに正しく表示されるようにしておくため、unknown型から絞り込んでいく
    const error = e;
    let text = 'エラーが発生しました。';
    if (error instanceof Object) {
        let obj;
        if ('error' in error) {
            // KintoneAllRecordsErrorクラスを想定
            obj = error.error;
        }
        else {
            obj = error;
        }
        if ('message' in obj && typeof obj.message === 'string') {
            // Errorクラスを想定
            text = obj.message;
        }
    }
    else if (typeof error === 'string') {
        text = error;
    }
    let errorDetail;
    if (error instanceof Object) {
        const stack = 'stack' in error ? error.stack : undefined;
        errorDetail = JSON.stringify({ ...error, stack }, null, 2);
    }
    else if (typeof error === 'string') {
        errorDetail = '（エラーの詳細情報はありません）';
    }
    else {
        errorDetail = String(error);
    }
    const div = document.createElement('div');
    if (error instanceof _1.GoqooError) {
        const url = `${location.origin}/k/${error.appId}/show#record=${error.recordId}`;
        div.innerHTML = `
    該当レコード: <a href="${url}" target="_blank">${url}</a>
    `;
    }
    const result = await (0, sweetalert_1.default)({
        icon: 'error',
        text,
        content: { element: div },
        buttons: {
            cancel: {
                visible: true,
                text: 'エラーの詳細を表示',
                value: 'detail',
            },
            confirm: true,
        },
    });
    if (result === 'detail') {
        const detail = text + '\n\n' + errorDetail;
        const isCopy = await (0, sweetalert_1.default)({
            content: {
                element: 'textarea',
                attributes: {
                    value: detail,
                    readOnly: true,
                    style: 'width: 100%; height: 20rem;',
                },
            },
            buttons: {
                confirm: {
                    text: 'クリップボードにコピーして閉じる',
                },
            },
        });
        isCopy && (0, clipboard_copy_1.default)(detail);
    }
    return result;
};
exports.errorDialog = errorDialog;
